@@ -4,33 +4,7 @@
 #
 # pylint: disable=import-outside-toplevel
 
-"""Command-line interface.
-
-Use ``gas <command>`` in terminal to operate on datasets.
-
-Use ``gas auth`` to authenticate the accessKey of gas.
-
-Use ``gas branch`` to list, create or delete branches.
-
-Use ``gas commit`` to commit drafts.
-
-Use ``gas config`` to configure the options when using gas CLI.
-
-Use ``gas cp`` to copy local data to a remote path.
-
-Use ``gas dataset`` to list, create or delete datasets.
-
-Use ``gas draft`` to list or create drafts.
-
-Use ``gas log`` to show commit logs.
-
-Use ``gas ls`` to list data under the path.
-
-Use ``gas rm`` to remove the remote data.
-
-Use ``gas tag`` to list, create or delete tags.
-
-"""
+"""Definitions of TensorBay Command-line Interface commands."""
 
 from functools import partial
 from typing import Iterable, Optional, Tuple
@@ -398,6 +372,10 @@ def tag(obj: ContextInfo, tbrn: str, name: str, is_delete: bool, sort: str) -> N
         "",
         "# Show text-based graphical commit logs.",
         "$ gas log --graph tb:<dataset_name>[@<revision>]",
+        "",
+        "# Show commit and open draft logs.",
+        "$ gas log --show-drafts tb:<dataset_name>[@<revision>]",
+        "",
     )
 )
 @click.argument("tbrn", type=str)
@@ -407,6 +385,7 @@ def tag(obj: ContextInfo, tbrn: str, name: str, is_delete: bool, sort: str) -> N
 @click.option("--oneline", is_flag=True, help="Limit commit message to oneline")
 @click.option("--all", "is_all", is_flag=True, help="Show all the commits of all branches")
 @click.option("--graph", is_flag=True, help="Show text-based graphical commits history")
+@click.option("--show-drafts", is_flag=True, help="Show open drafts along with the commits")
 @click.pass_obj
 def log(  # pylint: disable=too-many-arguments
     obj: ContextInfo,
@@ -415,6 +394,7 @@ def log(  # pylint: disable=too-many-arguments
     oneline: bool,
     is_all: bool,
     graph: bool,
+    show_drafts: bool,
 ) -> None:
     """Show commit logs.\f
 
@@ -425,11 +405,12 @@ def log(  # pylint: disable=too-many-arguments
         oneline: Whether to show a commit message in oneline.
         is_all: Whether to show all commits of all branches.
         graph: Whether to show graphical commit history.
+        show_drafts: Whether to log open drafts.
 
     """  # noqa: D301,D415
     from tensorbay.cli.log import _implement_log
 
-    _implement_log(obj, tbrn, max_count, oneline, is_all, graph)
+    _implement_log(obj, tbrn, max_count, oneline, is_all, graph, show_drafts)
 
 
 @command(
