@@ -438,3 +438,143 @@ def mock_get_users(mocker, is_valid):
         mock.side_effect = UnauthorizedError()
 
     return mock, response_data
+
+
+@function_fixture
+def mock_create_job(mocker):
+    """Mock the createJob OpenAPI.
+
+    Arguments:
+        mocker: The mocker fixture.
+
+    Returns:
+        The patched mocker and response data.
+
+    """
+    response_data = {"jobId": "123", "createdAt": 1}
+    return (
+        mocker.patch(
+            f"{gas.__name__}.Client.open_api_do",
+            return_value=mock_response(data=response_data),
+        ),
+        response_data,
+    )
+
+
+@function_fixture
+def mock_get_job(mocker, until_complete: bool = False):
+    """Mock the getJob OpenAPI.
+
+    Arguments:
+        mocker: The mocker fixture.
+        until_complete: Whether to update job information until it is complete.
+
+    Returns:
+        The patched mocker and response data.
+
+    """
+    response_data1 = {
+        "title": "test->main(abort)",
+        "jobId": "123",
+        "jobType": "squashAndMerge",
+        "arguments": {"title": "draft-1"},
+        "createdAt": 1,
+        "status": "QUEUING",
+        "errorMessage": "",
+        "description": "12",
+    }
+    response_data2 = {
+        "title": "test->main(abort)",
+        "jobId": "123",
+        "jobType": "squashAndMerge",
+        "arguments": {"title": "draft-1"},
+        "createdAt": 1,
+        "startedAt": 2,
+        "finishedAt": 3,
+        "status": "SUCCESS",
+        "errorMessage": "",
+        "result": {"draftNumber": 3},
+        "description": "12",
+    }
+    if not until_complete:
+        return (
+            mocker.patch(
+                f"{gas.__name__}.Client.open_api_do",
+                return_value=mock_response(data=response_data1),
+            ),
+            response_data1,
+        )
+    return (
+        mocker.patch(
+            f"{gas.__name__}.Client.open_api_do",
+            side_effect=[mock_response(data=response_data1), mock_response(data=response_data2)],
+        ),
+        [response_data1, response_data2],
+    )
+
+
+@function_fixture
+def mock_list_jobs(mocker):
+    """Mock the listJobs OpenAPI.
+
+    Arguments:
+        mocker: The mocker fixture.
+
+    Returns:
+        The patched mocker and response data.
+
+    """
+    response_data = {
+        "jobs": [
+            {
+                "title": "test->main(abort)",
+                "jobId": "123",
+                "jobType": "squashAndMerge",
+                "arguments": {"title": "draft-1"},
+                "createdAt": 1,
+                "status": "QUEUING",
+                "errorMessage": "",
+                "description": "12",
+            },
+            {
+                "title": "test->main(abort)",
+                "jobId": "234",
+                "jobType": "squashAndMerge",
+                "arguments": {"title": "draft-1"},
+                "createdAt": 1,
+                "status": "QUEUING",
+                "errorMessage": "",
+                "description": "12",
+            },
+        ],
+        "offset": 0,
+        "recordSize": 2,
+        "totalCount": 2,
+    }
+    return (
+        mocker.patch(
+            f"{gas.__name__}.Client.open_api_do",
+            return_value=mock_response(data=response_data),
+        ),
+        response_data,
+    )
+
+
+@function_fixture
+def mock_create_commit(mocker):
+    """Mock the createCommit OpenAPI.
+
+    Arguments:
+        mocker: The mocker fixture.
+
+    Returns:
+        The patched mocker and response data.
+
+    """
+    response_data = {"commitId": 1}
+    return (
+        mocker.patch(
+            f"{gas.__name__}.Client.open_api_do", return_value=mock_response(data=response_data)
+        ),
+        response_data,
+    )
