@@ -3,12 +3,7 @@
 # Copyright 2021 Graviti. Licensed under MIT License.
 #
 
-"""Polygon.
-
-:class:`Polygon` contains the coordinates of the vertexes of the polygon
-and provides :meth:`Polygon.area` to calculate the area of the polygon.
-
-"""
+"""The implementation of the TensorBay polygon."""
 
 from typing import Dict, Iterable, List, Mapping, Optional, Sequence, Type, TypeVar
 
@@ -173,8 +168,8 @@ class RLE(UserMutableSequence[int]):
 
     _data: List[int]
 
-    def __init__(self, rle: Optional[Iterable[int]]):
-        self._data = list(rle) if rle else []
+    def __init__(self, rle: Optional[Iterable[int]] = None):
+        self._data = list(rle) if rle is not None else []
 
     def _dumps(self) -> List[int]:
         return self._data
