@@ -3,26 +3,16 @@
 # Copyright 2021 Graviti. Licensed under MIT License.
 #
 
-"""Classification.
-
-:class:`ClassificationSubcatalog` defines the subcatalog for classification type of labels.
-
-:class:`Classification` defines the concept of classification label,
-which can apply to different types of data, such as images and texts.
-
-"""
+"""The implementation of the TensorBay classification label."""
 
 from typing import Any, Dict, Optional, Type, TypeVar
 
-from ..utility import SubcatalogTypeRegister, TypeRegister, common_loads
-from .basic import LabelType, SubcatalogBase, _LabelBase
-from .supports import AttributesMixin, CategoriesMixin
+from tensorbay.label.basic import SubcatalogBase, _LabelBase
+from tensorbay.label.supports import AttributesMixin, CategoriesMixin
+from tensorbay.utility import common_loads
 
 
-@SubcatalogTypeRegister(LabelType.CLASSIFICATION)
-class ClassificationSubcatalog(  # pylint: disable=too-many-ancestors
-    SubcatalogBase, CategoriesMixin, AttributesMixin
-):
+class ClassificationSubcatalog(SubcatalogBase, CategoriesMixin, AttributesMixin):
     """This class defines the subcatalog for classification type of labels.
 
     Attributes:
@@ -80,7 +70,6 @@ class ClassificationSubcatalog(  # pylint: disable=too-many-ancestors
     """
 
 
-@TypeRegister(LabelType.CLASSIFICATION)
 class Classification(_LabelBase):
     """This class defines the concept of classification label.
 
@@ -106,9 +95,7 @@ class Classification(_LabelBase):
 
     _T = TypeVar("_T", bound="Classification")
 
-    _label_attrs = ("category", "attributes")
-
-    _repr_attrs = _label_attrs
+    _repr_attrs = ("category", "attributes")
 
     def __init__(
         self,
