@@ -3,14 +3,8 @@
 # Copyright 2021 Graviti. Licensed under MIT License.
 #
 
-"""Common_loads method, EqMixin class.
+"""Common tools."""
 
-:meth:`common_loads` is a common method for loading an object from a dict or a list of dict.
-
-:class:`EqMixin` is a mixin class to support __eq__() method,
-which compares all the instance variables.
-
-"""
 
 from collections import defaultdict
 from functools import wraps
@@ -22,7 +16,6 @@ import numpy as np
 _T = TypeVar("_T")
 _CallableWithoutReturnValue = TypeVar("_CallableWithoutReturnValue", bound=Callable[..., None])
 
-
 MatrixType = Union[Sequence[Sequence[float]], np.ndarray]
 
 
@@ -42,7 +35,7 @@ def common_loads(object_class: Type[_T], contents: Any) -> _T:
     return obj
 
 
-class EqMixin:  # pylint: disable=too-few-public-methods
+class EqMixin:
     """A mixin class to support __eq__() method.
 
     The __eq__() method defined here compares all the instance variables.
