@@ -3,18 +3,23 @@
 # Copyright 2021 Graviti. Licensed under MIT License.
 #
 
-"""ReprType and ReprMixin.
-
-:class:`ReprType` is an enumeration type, which defines the repr strategy type and includes
-'INSTANCE', 'SEQUENCE', 'MAPPING'.
-
-:class:`ReprMixin` provides customized repr config and method.
-
-"""
+"""The implementation of the TensorBay repr."""
 
 from abc import ABC
 from enum import Enum, auto
-from typing import Any, Callable, Dict, Iterable, Mapping, Sequence, Tuple, Type, TypeVar, Union
+from typing import (
+    Any,
+    Callable,
+    ClassVar,
+    Dict,
+    Iterable,
+    Mapping,
+    Sequence,
+    Tuple,
+    Type,
+    TypeVar,
+    Union,
+)
 
 
 class ReprType(Enum):
@@ -32,7 +37,7 @@ class ReprType(Enum):
 class ReprMixin:
     """ReprMixin provides customized repr config and method."""
 
-    _repr_type = ReprType.INSTANCE
+    _repr_type: ClassVar[ReprType] = ReprType.INSTANCE
     _repr_attrs: Iterable[str] = ()
     _repr_maxlevel = 1
     _repr_non_empty = False
@@ -135,9 +140,8 @@ def _repr1(obj: Any, level: int, maxlevel: int, folding: bool) -> str:
         "repr" of the object.
 
     """
-    # pylint: disable=protected-access
-    printer_key = obj._repr_type if hasattr(obj, "_repr_type") else type(obj)
-    printer = _PRINTERS.get(printer_key, None)
+    class_: Type[Any] = type(obj)
+    printer = _PRINTERS.get(getattr(class_, "_repr_type", class_), None)
     return printer(obj, level, maxlevel, folding) if printer else repr(obj)
 
 
